grab.request — Grab 0.6.41 documentation

# `grab.request`

## Module Contents

### Classes

`Request` |

class grab.request.Request(method: str, url: str, *, headers: None | dict[str, Any] = None, timeout: None | int | Timeout = None, cookies: None | dict[str, Any] = None, encoding: None | str = None, proxy_type: None | str = None, proxy: None | str = None, proxy_userpwd: None | str = None, fields: Any = None, body: None | bytes = None, multipart: None | bool = None, document_type: None | str = None)
  get_full_url() → str
  _process_timeout_param(value: None | float | Timeout) → grab.util.timeout.Timeout